"use strict";

var generators = require('yeoman-generator');
module.exports = generators.Base.extend({
	prompting: function(){
		var done = this.async();
		console.log(done);
		var templates = [
			{
				name: 'icon'				
			},
			{
				name: 'info'
			},
			{
				name: 'multiline'
			},
			{
				name: 'feed'
			}];
		var prompts =[{
			type: 'input',
			name: 'instName',
			message: 'Institution name',
			default: 'collabco'
		},{
			type:'input',
			name: 'appName',
			message: 'Application Name',
			default: 'my'
		},
		{
			type: 'input',
			name: 'displayName',
			message: 'Display Name'
		},
		{
			type: 'input',
			name: 'description',
			message: 'Description'
		},
		{
			type: 'checkbox',
			name: 'templates',
			message: 'Tile Templates',
			choices:templates,
			validate: function(answers){
				if(answers.length < 1){
					return "You must select at least one template.";
				}
				else{
					return true;
				}
			}
		},
		{
			type: 'list',
			name: 'defTemplate',
			message: 'Default Template',
			choices: function(answers){
				return answers.templates;

			},
			default:function(answers){
				return answers.templates[0];
			},
			when:function(answers){
				return answers.templates.length > 1;
			}
		},
		{
			type: 'list',
			name: 'defSize',
			message: "Default Tile Size",
			choices:function(answers){
				var sizes = [{name:'Medium'},{name:'Wide'}];
				switch(answers.defTemplate){
					case 'icon':
						sizes = [
							{
								name:'Small',
								value: 0
							}];
						break;
					case 'info':
						sizes = [
							{
								name:'Medium',
								value: 1
							},
							{
								name:'Wide',
								value: 2
							}];
						break;
					case 'multiline':
						sizes = [
						{
							name:'Wide', 
							value: 2
						}];
						break;
					case 'feed':
						sizes = [
						{
							name:'Feed',
							value: 3
						},
						{
							name:'Wide Feed',
							value: 4
						},
						{
							name: 'Large Feed',
							value: 5
						}];
						break;
					}
				return sizes;
			},
				
			default:function(answers){
				var size = 'Medium';
				switch(answers.defTemplate){
					case 'Icon':
						size = 'Small';
						break;
					case 'Info':
						size = 'Medium';
						break;
					case 'Multiline':
						size = 'Wide';
						break;
					case 'Feed':
						size = 'Feed';
						break;
				}
				return size;
			}
		}];
		this.prompt(prompts).then(function(answers){
			console.log("I'm now here!");			
			this.props = answers;
			console.log(answers);
			done();
		}.bind(this));
	},
	writing: function(){
		console.log("I am here!!!!");
		var folderName = this.props.instName + '.' + this.props.appName;
		var capitalisedAppName = this.props.instName[0].toUpperCase() + this.props.instName.slice(1,this.props.instName.length)
		  + this.props.appName[0].toUpperCase() + this.props.appName.slice(1,this.props.appName.length);

		console.log('*******************************************');
		console.log('* Starting myday app scaffold...          *');
		console.log('*******************************************');
		console.log('');
		console.log('Scaffolding: ' +folderName +'/app.json');

		// app.json
		this.fs.copyTpl(
			this.templatePath('collabco.template/app.json'),
			this.destinationPath( folderName+'/app.json'),
			{
				appName: folderName,
				displayName: this.props.displayName,
				description: this.props.description,
				defTemplate: this.props.defTemplate,
				defSize: this.props.defSize
			});	

		console.log('Scaffolding: preview.json');
		//preview.json
		this.fs.copy(
			this.templatePath('collabco.template/preview.json'),
			this.destinationPath(folderName+'/preview.json')
			);	

		console.log('Scaffolding: language files');
		// language files
		this.fs.copyTpl(
			this.templatePath('collabco.template/lang/en-gb.json'),
			this.destinationPath(folderName+'/lang/en-gb.json'),
			{
				instName: this.props.instName,
				appName: this.props.appName
			});

		this.fs.copyTpl(
			this.templatePath('collabco.template/lang/cy.json'),
			this.destinationPath(folderName+'/lang/cy.json'),
			{
				instName: this.props.instName,
				appName: this.props.appName
			});

		this.fs.copyTpl(
			this.templatePath('collabco.template/lang/en-us.json'),
			this.destinationPath(folderName+'/lang/en-us.json'),
			{
				instName: this.props.instName,
				appName: this.props.appName
			});

		this.fs.copyTpl(
			this.templatePath('collabco.template/lang/gd-gb.json'),
			this.destinationPath(folderName+'/lang/gd-gb.json'),
			{
				instName: this.props.instName,
				appName: this.props.appName
			});

		this.fs.copyTpl(
			this.templatePath('collabco.template/lang/pl.json'),
			this.destinationPath(folderName+'/lang/pl.json'),
			{
				instName: this.props.instName,
				appName: this.props.appName
			});

		console.log('Scaffolding: tile and backstage files');
		// tile
		this.fs.copyTpl(
			this.templatePath('collabco.template/js/tile.js'),
			this.destinationPath(folderName+'/js/tile.js'),
			{
				fullAppName: folderName,
				instName: this.props.instName,
				appName: this.props.appName
			});	

		// backstage
		this.fs.copyTpl(
			this.templatePath('collabco.template/js/backstage.js'),
			this.destinationPath(folderName+'/js/backstage.js'),
			{
				fullAppName: folderName,
				appName: this.props.appName,
				capitalisedAppName: capitalisedAppName
			});	

		console.log('Scaffolding: controllers');
		// controller
		this.fs.copyTpl(
			this.templatePath('collabco.template/js/controllers/CollabcoTemplateCtrl.js'),
			this.destinationPath(folderName+'/js/controllers/' + capitalisedAppName +'Ctrl.js'),
			{
				fullAppName: folderName,
				capitalisedAppName: capitalisedAppName
			});

		console.log('Scaffolding: dummy service');
		// dummy service
		this.fs.copyTpl(
			this.templatePath('collabco.template/js/providers/CollabcoTemplateService.js'),
			this.destinationPath(folderName+'/js/providers/' + capitalisedAppName +'Service.js'),
			{
				fullAppName: folderName,
				capitalisedAppName: capitalisedAppName
			});	

		console.log('Scaffolding: image repository');
		// logo
		this.fs.copy(
			this.templatePath('collabco.template/images/logo.png'),
			this.destinationPath(folderName+'/images/logo.png')
			);	

		console.log('Scaffolding: HTML file');
		// html file
		this.fs.copyTpl(
			this.templatePath('collabco.template/html/main.html'),
			this.destinationPath(folderName+'/html/main.html'),
			{
				instName: this.props.instName,
				appName: this.props.appName
			});

		console.log('');
		console.log('Committing to disk...');	
		console.log('');
	}
  
});


